"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import stackl_client
from stackl_client.model.host_target import HostTarget


class TestHostTarget(unittest.TestCase):
    """HostTarget unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHostTarget(self):
        """Test HostTarget"""
        # FIXME: construct object with mandatory attributes with example values
        # model = HostTarget()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
