"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import unittest

import stackl_client
from stackl_client.api.stack_instances_api import StackInstancesApi  # noqa: E501


class TestStackInstancesApi(unittest.TestCase):
    """StackInstancesApi unit test stubs"""

    def setUp(self):
        self.api = StackInstancesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_stack_instance(self):
        """Test case for delete_stack_instance

        Delete Stack Instance  # noqa: E501
        """
        pass

    def test_get_stack_instance(self):
        """Test case for get_stack_instance

        Get Stack Instance  # noqa: E501
        """
        pass

    def test_get_stack_instances(self):
        """Test case for get_stack_instances

        Get Stack Instances  # noqa: E501
        """
        pass

    def test_post_stack_instance(self):
        """Test case for post_stack_instance

        Post Stack Instance  # noqa: E501
        """
        pass

    def test_put_stack_instance(self):
        """Test case for put_stack_instance

        Put Stack Instance  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
