"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import stackl_client
from stackl_client.model.host_target import HostTarget
from stackl_client.model.stack_instance_service import StackInstanceService
from stackl_client.model.stack_instance_status import StackInstanceStatus
from stackl_client.model.stack_stage import StackStage
globals()['HostTarget'] = HostTarget
globals()['StackInstanceService'] = StackInstanceService
globals()['StackInstanceStatus'] = StackInstanceStatus
globals()['StackStage'] = StackStage
from stackl_client.model.stack_instance import StackInstance


class TestStackInstance(unittest.TestCase):
    """StackInstance unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStackInstance(self):
        """Test StackInstance"""
        # FIXME: construct object with mandatory attributes with example values
        # model = StackInstance()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
