"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import unittest

import stackl_client
from stackl_client.api.infrastructure_base_api import InfrastructureBaseApi  # noqa: E501


class TestInfrastructureBaseApi(unittest.TestCase):
    """InfrastructureBaseApi unit test stubs"""

    def setUp(self):
        self.api = InfrastructureBaseApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_infrastructure_base(self):
        """Test case for delete_infrastructure_base

        Delete Infrastructure Base  # noqa: E501
        """
        pass

    def test_get_infrastructure_base_by_type(self):
        """Test case for get_infrastructure_base_by_type

        Get Infrastructure Base By Type  # noqa: E501
        """
        pass

    def test_get_infrastructure_base_by_type_and_name(self):
        """Test case for get_infrastructure_base_by_type_and_name

        Get Infrastructure Base By Type And Name  # noqa: E501
        """
        pass

    def test_post_infrastructure_base(self):
        """Test case for post_infrastructure_base

        Post Infrastructure Base  # noqa: E501
        """
        pass

    def test_put_infrastructure_base(self):
        """Test case for put_infrastructure_base

        Put Infrastructure Base  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
