"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import unittest

import stackl_client
from stackl_client.api.outputs_api import OutputsApi  # noqa: E501


class TestOutputsApi(unittest.TestCase):
    """OutputsApi unit test stubs"""

    def setUp(self):
        self.api = OutputsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_outputs(self):
        """Test case for add_outputs

        Add Outputs  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
