"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import unittest

import stackl_client
from stackl_client.api.stack_infrastructure_templates_api import StackInfrastructureTemplatesApi  # noqa: E501


class TestStackInfrastructureTemplatesApi(unittest.TestCase):
    """StackInfrastructureTemplatesApi unit test stubs"""

    def setUp(self):
        self.api = StackInfrastructureTemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_stack_infrastructure_template(self):
        """Test case for delete_stack_infrastructure_template

        Delete Stack Infrastructure Template  # noqa: E501
        """
        pass

    def test_get_stack_infrastructure_template_by_name(self):
        """Test case for get_stack_infrastructure_template_by_name

        Get Stack Infrastructure Template By Name  # noqa: E501
        """
        pass

    def test_get_stack_infrastructure_templates(self):
        """Test case for get_stack_infrastructure_templates

        Get Stack Infrastructure Templates  # noqa: E501
        """
        pass

    def test_post_stack_infrastructure_template(self):
        """Test case for post_stack_infrastructure_template

        Post Stack Infrastructure Template  # noqa: E501
        """
        pass

    def test_put_stack_infrastructure_template(self):
        """Test case for put_stack_infrastructure_template

        Put Stack Infrastructure Template  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
