"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import unittest

import stackl_client
from stackl_client.api.snapshots_api import SnapshotsApi  # noqa: E501


class TestSnapshotsApi(unittest.TestCase):
    """SnapshotsApi unit test stubs"""

    def setUp(self):
        self.api = SnapshotsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_snapshot(self):
        """Test case for create_snapshot

        Create Snapshot  # noqa: E501
        """
        pass

    def test_delete_snapshot(self):
        """Test case for delete_snapshot

        Delete Snapshot  # noqa: E501
        """
        pass

    def test_get_snapshot(self):
        """Test case for get_snapshot

        Get Snapshot  # noqa: E501
        """
        pass

    def test_get_snapshots(self):
        """Test case for get_snapshots

        Get Snapshots  # noqa: E501
        """
        pass

    def test_restore_latest_snapshot(self):
        """Test case for restore_latest_snapshot

        Restore Latest Snapshot  # noqa: E501
        """
        pass

    def test_restore_snapshot(self):
        """Test case for restore_snapshot

        Restore Snapshot  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
