"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import stackl_client
from stackl_client.model.stack_application_template_service import StackApplicationTemplateService
from stackl_client.model.stack_stage import StackStage
globals()['StackApplicationTemplateService'] = StackApplicationTemplateService
globals()['StackStage'] = StackStage
from stackl_client.model.stack_instance_invocation import StackInstanceInvocation


class TestStackInstanceInvocation(unittest.TestCase):
    """StackInstanceInvocation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStackInstanceInvocation(self):
        """Test StackInstanceInvocation"""
        # FIXME: construct object with mandatory attributes with example values
        # model = StackInstanceInvocation()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
